@@ -19,8 +19,4 @@ def run_experiment(experiment_id,auth_key=''):
   project = experiment['project']
   target_column = project['targetColumn']
   task_type = project['taskType']
-  try:
-    generate_file(pipeline,target_column,task_type)
-  except:
-    print("Error generating file")
-    return
+  generate_file(pipeline,task_type=task_type,target_column=target_column)
\ No newline at end of file
