@@ -12,5 +12,5 @@ def temp_train_test_split(params):
 
 
 def temp_train_model(params):
-    return f"Model = huble.sklearn.train_model(data=data, model=model, column={params['target_column']})"
+    return f"Model = huble.sklearn.train_model(data=training_dataset, model=model, column='{params['target_column']}')"
     
\ No newline at end of file
