@@ -28,7 +28,7 @@ class Graph:
                 self.topologicalSortUtil(i, visited, stack)
         return(stack[::-1]) 
  
-def generate_file(graph, colab=False,target_column,task_type):
+def generate_file(graph, target_column,task_type,colab=False):
     g = Graph(len(graph['nodes']))
     map = {}
     j=0
@@ -48,13 +48,17 @@ def generate_file(graph, colab=False,target_column,task_type):
         for j in range(len(graph['nodes'])):
             if i == graph['nodes'][j]['id']:
                 steps_list[(graph['nodes'][j]['data']['name'])]=graph['nodes'][j]['data']['node_type']
-
-    with open("/content/output.py", "w") as f:
+    if colab:
+      output_file = "/content/output.py"
+    else:
+      output_file = "output.py"
+    with open(output_file, "w") as f:
         f.write("import huble\n")
         
         for i in steps_list:
             for node in graph['nodes']:
                 if i == node['data']['name']:
+                    print(node['data']['name'])
                     if steps_list[i]=='preprocess':
                         f.write(preprocess_generate(node))
                         f.write("\n")
@@ -65,7 +69,7 @@ def generate_file(graph, colab=False,target_column,task_type):
                         f.write(essentials_generate(node))
                         f.write("\n")
                     elif steps_list[i] == 'evaluate_model':
-                        f.write(f"metrics = huble.util.evaluate_model(model=Model, test_dataset=test_dataset, target_column= '{target_column}, task_type='{task_type}' )")
+                        f.write(f"metrics = huble.util.evaluate_model(model=Model, test_dataset=test_dataset, target_column= '{target_column}', task_type='{task_type}' )")
                         f.write("\n")
                     elif steps_list[i] == 'primary_dataset':
                         f.write(f"data=huble.util.load_dataset('{node['data']['url']}')")
