@@ -3,8 +3,9 @@ import requests
 
 
 def load_dataset(url) -> pd.DataFrame:
-    local_filename = "test.csv"  # url.split('/')[-1]
+    local_filename = url.split('/')[-1]
     # NOTE the stream=True parameter below
+    
     with requests.get(url, stream=True) as r:
         r.raise_for_status()
         with open(local_filename, "wb") as f:
